PaymentData class
Constructors
- PaymentData({required CustomerDetails customer, required int amount, required String method, required String transactionId, required DateTime time, String status = "pending"})
Properties
- amount → int
-
final
- customer → CustomerDetails
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- time → DateTime
-
final
- transactionId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Optional: Firebase conversion (recommended)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited