PaymentMethod class

Constructors

PaymentMethod({required String type, required String number, required String assetPath, required Color color})
PaymentMethod.bkash(String number)
bKash
factory
PaymentMethod.nagad(String number)
Nagad
factory
PaymentMethod.pathao(String number)
Pathao Pay
factory
PaymentMethod.rocket(String number)
Rocket
factory
PaymentMethod.surecash(String number)
SureCash
factory
PaymentMethod.upay(String number)
Upay
factory

Properties

assetPath String
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
number String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited